==> MIDITrail-Ver.1.0.4src.zip: MIDITrail/MIDITrail/MTScenePianoRoll3D.h <==
//******************************************************************************
//
// MIDITrail / MTScenePianoRoll3D
//
// sAm[3DV[`NX
//
// Copyright (C) 2010 WADA Masashi. All Rights Reserved.
//
//******************************************************************************

#pragma once

#include <d3d9.h>
#include <d3dx9.h>
#include "DXDirLight.h"
#include "MTScene.h"
#include "MTFirstPersonCam.h"
#include "MTNoteBox.h"
#include "MTNoteRipple.h"
#include "MTNoteDesign.h"
#include "MTNotePitchBend.h"
#include "MTGridBox.h"
#include "MTPictBoard.h"
#include "MTDashboard.h"
#include "MTStars.h"
#include "MTDynamicCaption.h"
#include "MTTimeIndicator.h"
#include "SMIDILib.h"

using namespace SMIDILib;


//******************************************************************************
// sAm[3DV[`NX
//******************************************************************************
class MTScenePianoRoll3D : public MTScene
{
public:

	//RXgN^^fXgN^l
	MTScenePianoRoll3D();
	~MTScenePianoRoll3D();

	//̎擾
	const TCHAR* GetName();

	//
	virtual int Create(
			HWND hWnd,
			LPDIRECT3DDEVICE9 pD3DDevice,
			SMSeqData* pSeqData
		);

	//ϊ
	int Transform(LPDIRECT3DDEVICE9 pD3DDevice);

	//`
	int Draw(LPDIRECT3DDEVICE9 pD3DDevice);

	//j
	void Release();

	//FPSo^
	void SetFPS(double fps);

	//EBhENbNCxgM
	int OnWindowClicked(
			unsigned long button,
			unsigned long wParam,
			unsigned long lParam
		);

	//tJnCxgM
	int OnPlayStart();

	//tICxgM
	int OnPlayEnd();

	//V[PTbZ[WM
	int OnRecvSequencerMsg(
			unsigned long wParam,
			unsigned long lParam
		);

	//߂
	int Rewind();

	//_擾
	void GetDefaultViewpoint(D3DXVECTOR3* pVector, float* pPhi, float* pTheta);
	void GetViewpoint(D3DXVECTOR3* pVector, float* pPhi, float* pTheta);
	void SetViewpoint(D3DXVECTOR3 vector, float phi, float theta);

	//_Zbg
	void ResetViewpoint();

	void SetEffect(MTScene::EffectType type, bool isEnable);

protected:

	//CgL
	BOOL m_IsEnableLight;

private:

	//Cg
	DXDirLight m_DirLight;

	//l̃J
	MTFirstPersonCam m_FirstPersonCam;

	//`IuWFNg
	MTNoteBox m_NoteBox;
	MTNoteRipple m_NoteRipple;
	MTNotePitchBend m_NotePitchBend;
	MTGridBox m_GridBox;
	MTPictBoard m_PictBoard;
	MTDashboard m_Dashboard;
	MTStars m_Stars;
	MTTimeIndicator m_TimeIndicator;
	MTDynamicCaption m_FPS;

	//}EXړ[h
	bool m_IsMouseCamMode;

	//][h
	bool m_IsAutoRollMode;

	//_
	D3DXVECTOR3 m_ViewpointVector;
	float m_ViewpointPhi;
	float m_ViewpointTheta;

	//m[gfUCIuWFNg
	MTNoteDesign m_NoteDesign;

	void _Reset();

};

==> MIDITrail-Ver.1.1.1src.zip: MIDITrail/MIDITrail/MTScenePianoRoll3D.h <==
//******************************************************************************
//
// MIDITrail / MTScenePianoRoll3D
//
// sAm[3DV[`NX
//
// Copyright (C) 2010 WADA Masashi. All Rights Reserved.
//
//******************************************************************************

#pragma once

#include <d3d9.h>
#include <d3dx9.h>
#include "DXDirLight.h"
#include "MTScene.h"
#include "MTFirstPersonCam.h"
#include "MTNoteBox.h"
#include "MTNoteRipple.h"
#include "MTNoteDesign.h"
#include "MTNotePitchBend.h"
#include "MTGridBox.h"
#include "MTPictBoard.h"
#include "MTDashboard.h"
#include "MTStars.h"
#include "MTTimeIndicator.h"
#include "SMIDILib.h"

using namespace SMIDILib;


//******************************************************************************
// sAm[3DV[`NX
//******************************************************************************
class MTScenePianoRoll3D : public MTScene
{
public:

	//RXgN^^fXgN^l
	MTScenePianoRoll3D();
	~MTScenePianoRoll3D();

	//̎擾
	const TCHAR* GetName();

	//
	virtual int Create(
			HWND hWnd,
			LPDIRECT3DDEVICE9 pD3DDevice,
			SMSeqData* pSeqData
		);

	//ϊ
	int Transform(LPDIRECT3DDEVICE9 pD3DDevice);

	//`
	int Draw(LPDIRECT3DDEVICE9 pD3DDevice);

	//j
	void Release();

	//EBhENbNCxgM
	int OnWindowClicked(
			unsigned long button,
			unsigned long wParam,
			unsigned long lParam
		);

	//tJnCxgM
	int OnPlayStart();

	//tICxgM
	int OnPlayEnd();

	//V[PTbZ[WM
	int OnRecvSequencerMsg(
			unsigned long wParam,
			unsigned long lParam
		);

	//߂
	int Rewind();

	//_擾^o^
	void GetDefaultViewParam(MTViewParamMap* pParamMap);
	void GetViewParam(MTViewParamMap* pParamMap);
	void SetViewParam(MTViewParamMap* pParamMap);

	//_Zbg
	void ResetViewpoint();

	void SetEffect(MTScene::EffectType type, bool isEnable);

protected:

	//CgL
	BOOL m_IsEnableLight;

private:

	//Cg
	DXDirLight m_DirLight;

	//l̃J
	MTFirstPersonCam m_FirstPersonCam;

	//`IuWFNg
	MTNoteBox m_NoteBox;
	MTNoteRipple m_NoteRipple;
	MTNotePitchBend m_NotePitchBend;
	MTGridBox m_GridBox;
	MTPictBoard m_PictBoard;
	MTDashboard m_Dashboard;
	MTStars m_Stars;
	MTTimeIndicator m_TimeIndicator;

	//}EXړ[h
	bool m_IsMouseCamMode;

	//][h
	bool m_IsAutoRollMode;

	//_
	MTViewParamMap m_ViewParamMap;

	//m[gfUCIuWFNg
	MTNoteDesign m_NoteDesign;

	void _Reset();

};
